pub struct CheckRunsDiscover;Trait Implementations
Sourceimpl GraphQLQuery for CheckRunsDiscover
impl GraphQLQuery for CheckRunsDiscover
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for CheckRunsDiscover
impl RefUnwindSafe for CheckRunsDiscover
impl Send for CheckRunsDiscover
impl Sync for CheckRunsDiscover
impl Unpin for CheckRunsDiscover
impl UnsafeUnpin for CheckRunsDiscover
impl UnwindSafe for CheckRunsDiscover