pub struct CheckRunsGetSimple;Trait Implementations
Sourceimpl GraphQLQuery for CheckRunsGetSimple
impl GraphQLQuery for CheckRunsGetSimple
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for CheckRunsGetSimple
impl RefUnwindSafe for CheckRunsGetSimple
impl Send for CheckRunsGetSimple
impl Sync for CheckRunsGetSimple
impl Unpin for CheckRunsGetSimple
impl UnsafeUnpin for CheckRunsGetSimple
impl UnwindSafe for CheckRunsGetSimple