pub struct CheckRunsGetWithPages;Trait Implementations
Sourceimpl GraphQLQuery for CheckRunsGetWithPages
impl GraphQLQuery for CheckRunsGetWithPages
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for CheckRunsGetWithPages
impl RefUnwindSafe for CheckRunsGetWithPages
impl Send for CheckRunsGetWithPages
impl Sync for CheckRunsGetWithPages
impl Unpin for CheckRunsGetWithPages
impl UnsafeUnpin for CheckRunsGetWithPages
impl UnwindSafe for CheckRunsGetWithPages