pub struct ClosePullRequest;Trait Implementations
Sourceimpl GraphQLQuery for ClosePullRequest
impl GraphQLQuery for ClosePullRequest
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for ClosePullRequest
impl RefUnwindSafe for ClosePullRequest
impl Send for ClosePullRequest
impl Sync for ClosePullRequest
impl Unpin for ClosePullRequest
impl UnsafeUnpin for ClosePullRequest
impl UnwindSafe for ClosePullRequest