pub struct ConvertPullRequestToDraft;Trait Implementations
Sourceimpl GraphQLQuery for ConvertPullRequestToDraft
impl GraphQLQuery for ConvertPullRequestToDraft
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for ConvertPullRequestToDraft
impl RefUnwindSafe for ConvertPullRequestToDraft
impl Send for ConvertPullRequestToDraft
impl Sync for ConvertPullRequestToDraft
impl Unpin for ConvertPullRequestToDraft
impl UnsafeUnpin for ConvertPullRequestToDraft
impl UnwindSafe for ConvertPullRequestToDraft