pub struct GetDefaultBranch;Trait Implementations
Sourceimpl GraphQLQuery for GetDefaultBranch
impl GraphQLQuery for GetDefaultBranch
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for GetDefaultBranch
impl RefUnwindSafe for GetDefaultBranch
impl Send for GetDefaultBranch
impl Sync for GetDefaultBranch
impl Unpin for GetDefaultBranch
impl UnsafeUnpin for GetDefaultBranch
impl UnwindSafe for GetDefaultBranch