pub struct GetPrByHead;Trait Implementations
Sourceimpl GraphQLQuery for GetPrByHead
impl GraphQLQuery for GetPrByHead
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for GetPrByHead
impl RefUnwindSafe for GetPrByHead
impl Send for GetPrByHead
impl Sync for GetPrByHead
impl Unpin for GetPrByHead
impl UnsafeUnpin for GetPrByHead
impl UnwindSafe for GetPrByHead