pub struct GetRepoId;Trait Implementations
Sourceimpl GraphQLQuery for GetRepoId
impl GraphQLQuery for GetRepoId
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for GetRepoId
impl RefUnwindSafe for GetRepoId
impl Send for GetRepoId
impl Sync for GetRepoId
impl Unpin for GetRepoId
impl UnsafeUnpin for GetRepoId
impl UnwindSafe for GetRepoId