pub struct GetRepositoryCollaborators;Trait Implementations
Sourceimpl GraphQLQuery for GetRepositoryCollaborators
impl GraphQLQuery for GetRepositoryCollaborators
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for GetRepositoryCollaborators
impl RefUnwindSafe for GetRepositoryCollaborators
impl Send for GetRepositoryCollaborators
impl Sync for GetRepositoryCollaborators
impl Unpin for GetRepositoryCollaborators
impl UnsafeUnpin for GetRepositoryCollaborators
impl UnwindSafe for GetRepositoryCollaborators