pub struct GetRepositoryRulesets;Trait Implementations
Sourceimpl GraphQLQuery for GetRepositoryRulesets
impl GraphQLQuery for GetRepositoryRulesets
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for GetRepositoryRulesets
impl RefUnwindSafe for GetRepositoryRulesets
impl Send for GetRepositoryRulesets
impl Sync for GetRepositoryRulesets
impl Unpin for GetRepositoryRulesets
impl UnsafeUnpin for GetRepositoryRulesets
impl UnwindSafe for GetRepositoryRulesets