pub struct GetRulesetRequiredChecks;Trait Implementations
Sourceimpl GraphQLQuery for GetRulesetRequiredChecks
impl GraphQLQuery for GetRulesetRequiredChecks
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for GetRulesetRequiredChecks
impl RefUnwindSafe for GetRulesetRequiredChecks
impl Send for GetRulesetRequiredChecks
impl Sync for GetRulesetRequiredChecks
impl Unpin for GetRulesetRequiredChecks
impl UnsafeUnpin for GetRulesetRequiredChecks
impl UnwindSafe for GetRulesetRequiredChecks