pub struct MarkPullRequestReadyForReview;Trait Implementations
Sourceimpl GraphQLQuery for MarkPullRequestReadyForReview
impl GraphQLQuery for MarkPullRequestReadyForReview
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for MarkPullRequestReadyForReview
impl RefUnwindSafe for MarkPullRequestReadyForReview
impl Send for MarkPullRequestReadyForReview
impl Sync for MarkPullRequestReadyForReview
impl Unpin for MarkPullRequestReadyForReview
impl UnsafeUnpin for MarkPullRequestReadyForReview
impl UnwindSafe for MarkPullRequestReadyForReview