pub struct UpdatePullRequest;Trait Implementations
Sourceimpl GraphQLQuery for UpdatePullRequest
impl GraphQLQuery for UpdatePullRequest
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for UpdatePullRequest
impl RefUnwindSafe for UpdatePullRequest
impl Send for UpdatePullRequest
impl Sync for UpdatePullRequest
impl Unpin for UpdatePullRequest
impl UnsafeUnpin for UpdatePullRequest
impl UnwindSafe for UpdatePullRequest